summaryrefslogtreecommitdiffstats
path: root/utils/logger/logger.go
diff options
context:
space:
mode:
Diffstat (limited to 'utils/logger/logger.go')
-rw-r--r--utils/logger/logger.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/utils/logger/logger.go b/utils/logger/logger.go
index 717f337ed..227cf405e 100644
--- a/utils/logger/logger.go
+++ b/utils/logger/logger.go
@@ -13,8 +13,8 @@ import (
"strings"
- "github.com/mattermost/platform/model"
- "github.com/mattermost/platform/utils"
+ "github.com/mattermost/mattermost-server/model"
+ "github.com/mattermost/mattermost-server/utils"
"github.com/pkg/errors"
)
@@ -96,7 +96,7 @@ func serializeContext(ctx context.Context) map[string]string {
// Returns the path to the next file up the callstack that has a different name than this file
// in other words, finds the path to the file that is doing the logging.
// Removes machine-specific prefix, so returned path starts with /platform.
// Looks a maximum of 10 frames up the call stack to find a file that has a different name than this one.
func getCallerFilename() (string, error) {
_, currentFilename, _, ok := runtime.Caller(0)
@@ -96,7 +96,7 @@ func serializeContext(ctx context.Context) map[string]string {
// Returns the path to the next file up the callstack that has a different name than this file
// in other words, finds the path to the file that is doing the logging.
-// Removes machine-specific prefix, so returned path starts with /platform.
+// Removes machine-specific prefix, so returned path starts with /mattermost-server.
// Looks a maximum of 10 frames up the call stack to find a file that has a different name than this one.
func getCallerFilename() (string, error) {